@@ -212,7 +212,11 @@ public class HttpServicePlugin extends HttpServlet
 
         final PrintWriter pw = resp.getWriter();
 
-        printForm(pw, req.getParameter(ATTR_TEST), req.getParameter(ATTR_MSG));
+        String path = req.getContextPath() + req.getServletPath();
+        if ( req.getPathInfo() != null ) {
+            path = path + req.getPathInfo();
+        }
+        printForm(pw, req.getParameter(ATTR_TEST), req.getParameter(ATTR_MSG), path);
 
         printRuntimeDetails(pw, dto.serviceDTO);
 
@@ -233,7 +237,7 @@ public class HttpServicePlugin extends HttpServlet
         pw.println("<br/>");
     }
 
-    private void printForm(final PrintWriter pw, final String value, final String msg)
+    private void printForm(final PrintWriter pw, final String value, final String msg, final String path)
     {
         pw.println("<table class='content' cellpadding='0' cellspacing='0' width='100%'>");
 
@@ -248,7 +252,9 @@ public class HttpServicePlugin extends HttpServlet
         pw.println("<tr class='content'>");
         pw.println("<td class='content'>Test</td>");
         pw.print("<td class='content' colspan='2'>");
-        pw.print("<form method='post'>");
+        pw.print("<form method='POST' action='");
+        pw.print(path);
+        pw.print("'>");
         pw.print("<input type='text' name='" + ATTR_TEST + "' value='");
         if (value != null) {
             pw.print(escapeXml(value));
@@ -351,6 +357,7 @@ public class HttpServicePlugin extends HttpServlet
             odd = printRow(pw, odd, prop.getKey(), getValueAsString(prop.getValue()));
         }
         pw.println("</table>");
+        pw.println("<br/>");
     }
 
     private boolean printRow(final PrintWriter pw, final boolean odd, final String...columns)
@@ -393,6 +400,21 @@ public class HttpServicePlugin extends HttpServlet
         return path;
     }
 
+    private boolean printServiceRankingRow(final PrintWriter pw, final long serviceId, final boolean odd)
+    {
+        int ranking = 0;
+        final ServiceReference<?> ref = this.getServiceReference(serviceId);
+        if ( ref != null )
+        {
+            final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
+            if ( obj instanceof Integer)
+            {
+                ranking = (Integer)obj;
+            }
+        }
+        return printRow(pw, odd, "${ranking}", String.valueOf(ranking));
+    }
+
     private void printContextDetails(final PrintWriter pw, final ServletContextDTO dto)
     {
         pw.print("<p class=\"statline ui-state-highlight\">${Servlet Context} '");
@@ -408,6 +430,7 @@ public class HttpServicePlugin extends HttpServlet
         pw.println("</tr></thead>");
         odd = printRow(pw, odd, "${Path}", getContextPath(dto.contextPath));
         odd = printRow(pw, odd, "${service.id}", String.valueOf(dto.serviceId));
+        odd = printServiceRankingRow(pw, dto.serviceId, odd);
         pw.println("</table>");
 
         printServletDetails(pw, dto);
@@ -415,6 +438,8 @@ public class HttpServicePlugin extends HttpServlet
         printResourceDetails(pw, dto);
         printErrorPageDetails(pw, dto);
         printListenerDetails(pw, dto);
+
+        pw.println("<br/>");
     }
 
     private void printFailedContextDetails(final PrintWriter pw, final FailedServletContextDTO dto)
@@ -436,6 +461,20 @@ public class HttpServicePlugin extends HttpServlet
         pw.println("</table>");
     }
 
+    private void appendServiceRanking(final StringBuilder sb, final ServiceReference<?> ref)
+    {
+        int ranking = 0;
+        if ( ref != null )
+        {
+            final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
+            if ( obj instanceof Integer)
+            {
+                ranking = (Integer)obj;
+            }
+        }
+        sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
+    }
+
     private void printFilterDetails(final PrintWriter pw, final ServletContextDTO dto)
     {
         if ( dto.filterDTOs.length == 0 )
@@ -456,21 +495,12 @@ public class HttpServicePlugin extends HttpServlet
         boolean odd = true;
         for (final FilterDTO filter : dto.filterDTOs)
         {
-            final StringBuilder sb = new StringBuilder();
             final ServiceReference<?> ref = this.getServiceReference(filter.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
+            final StringBuilder sb = new StringBuilder();
+            sb.append("${service.id} : ").append(String.valueOf(filter.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             sb.append("${async} : ").append(String.valueOf(filter.asyncSupported)).append("\n");
             sb.append("${dispatcher} : ").append(getValueAsString(filter.dispatcher)).append("\n");
-            sb.append("${service.id} : ").append(String.valueOf(filter.serviceId)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -534,19 +564,10 @@ public class HttpServicePlugin extends HttpServlet
             final StringBuilder sb = new StringBuilder();
             sb.append("${reason} : ").append(getErrorText(filter.failureReason)).append("\n");
             final ServiceReference<?> ref = this.getServiceReference(filter.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
+            sb.append("${service.id} : ").append(String.valueOf(filter.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             sb.append("${async} : ").append(String.valueOf(filter.asyncSupported)).append("\n");
             sb.append("${dispatcher} : ").append(getValueAsString(filter.dispatcher)).append("\n");
-            sb.append("${service.id} : ").append(String.valueOf(filter.serviceId)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -617,18 +638,9 @@ public class HttpServicePlugin extends HttpServlet
         {
             final StringBuilder sb = new StringBuilder();
             final ServiceReference<?> ref = this.getServiceReference(servlet.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
-            sb.append("${async} : ").append(String.valueOf(servlet.asyncSupported)).append("\n");
             sb.append("${service.id} : ").append(String.valueOf(servlet.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
+            sb.append("${async} : ").append(String.valueOf(servlet.asyncSupported)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -670,18 +682,9 @@ public class HttpServicePlugin extends HttpServlet
             final StringBuilder sb = new StringBuilder();
             sb.append("${reason} : ").append(getErrorText(servlet.failureReason)).append("\n");
             final ServiceReference<?> ref = this.getServiceReference(servlet.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
-            sb.append("${async} : ").append(String.valueOf(servlet.asyncSupported)).append("\n");
             sb.append("${service.id} : ").append(String.valueOf(servlet.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
+            sb.append("${async} : ").append(String.valueOf(servlet.asyncSupported)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -724,17 +727,8 @@ public class HttpServicePlugin extends HttpServlet
         {
             final StringBuilder sb = new StringBuilder();
             final ServiceReference<?> ref = this.getServiceReference(rsrc.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
             sb.append("${service.id} : ").append(String.valueOf(rsrc.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -776,17 +770,8 @@ public class HttpServicePlugin extends HttpServlet
             final StringBuilder sb = new StringBuilder();
             sb.append("${reason} : ").append(getErrorText(rsrc.failureReason)).append("\n");
             final ServiceReference<?> ref = this.getServiceReference(rsrc.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
             sb.append("${service.id} : ").append(String.valueOf(rsrc.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -829,18 +814,9 @@ public class HttpServicePlugin extends HttpServlet
         {
             final StringBuilder sb = new StringBuilder();
             final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
-            sb.append("${async} : ").append(String.valueOf(ep.asyncSupported)).append("\n");
             sb.append("${service.id} : ").append(String.valueOf(ep.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
+            sb.append("${async} : ").append(String.valueOf(ep.asyncSupported)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -886,18 +862,9 @@ public class HttpServicePlugin extends HttpServlet
             final StringBuilder sb = new StringBuilder();
             sb.append("${reason} : ").append(getErrorText(ep.failureReason)).append("\n");
             final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
-            sb.append("${async} : ").append(String.valueOf(ep.asyncSupported)).append("\n");
             sb.append("${service.id} : ").append(String.valueOf(ep.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
+            sb.append("${async} : ").append(String.valueOf(ep.asyncSupported)).append("\n");
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -943,17 +910,8 @@ public class HttpServicePlugin extends HttpServlet
         {
             final StringBuilder sb = new StringBuilder();
             final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
             sb.append("${service.id} : ").append(String.valueOf(ep.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -993,17 +951,8 @@ public class HttpServicePlugin extends HttpServlet
             final StringBuilder sb = new StringBuilder();
             sb.append("${reason} : ").append(getErrorText(ep.failureReason)).append("\n");
             final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-            if ( ref != null )
-            {
-                int ranking = 0;
-                final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                if ( obj instanceof Integer)
-                {
-                    ranking = (Integer)obj;
-                }
-                sb.append("${ranking} : ").append(String.valueOf(ranking)).append("\n");
-            }
             sb.append("${service.id} : ").append(String.valueOf(ep.serviceId)).append("\n");
+            appendServiceRanking(sb, ref);
             if ( ref != null )
             {
                 sb.append("${bundle} : ");
@@ -1023,6 +972,23 @@ public class HttpServicePlugin extends HttpServlet
         pw.println("</table>");
     }
 
+    private void printServiceIdAndRanking(final PrintWriter pw, final ServiceReference<?> ref, final long serviceId)
+    {
+        pw.print("service.id : ");
+        pw.println(String.valueOf(serviceId));
+        int ranking = 0;
+        if ( ref != null )
+        {
+            final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
+            if ( obj instanceof Integer)
+            {
+                ranking = (Integer)obj;
+            }
+        }
+        pw.print("Ranking : ");
+        pw.println(String.valueOf(ranking));
+    }
+
     /**
      * @see org.apache.felix.webconsole.ConfigurationPrinter#printConfiguration(java.io.PrintWriter)
      */
@@ -1051,8 +1017,7 @@ public class HttpServicePlugin extends HttpServlet
 
             pw.print("Path : ");
             pw.println(getContextPath(ctxDto.contextPath));
-            pw.print("service.id : ");
-            pw.println(String.valueOf(ctxDto.serviceId));
+            printServiceIdAndRanking(pw, this.getServiceReference(ctxDto.serviceId), ctxDto.serviceId);
             pw.println();
             if ( ctxDto.servletDTOs.length > 0 )
             {
@@ -1064,22 +1029,9 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print("Name : ");
                     pw.println(servlet.name);
                     final ServiceReference<?> ref = this.getServiceReference(servlet.serviceId);
-                    if ( ref != null )
-                    {
-                        int ranking = 0;
-                        final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                        if ( obj instanceof Integer)
-                        {
-                            ranking = (Integer)obj;
-                        }
-                        pw.print("Ranking : ");
-                        pw.println(String.valueOf(ranking));
-                    }
+                    printServiceIdAndRanking(pw, ref, servlet.serviceId);
                     pw.print("async : ");
                     pw.println(String.valueOf(servlet.asyncSupported));
-                    pw.print("service.id : ");
-                    pw.println(String.valueOf(servlet.serviceId));
-                    pw.println();
                     if ( ref != null )
                     {
                         pw.print("Bundle : ");
@@ -1088,6 +1040,7 @@ public class HttpServicePlugin extends HttpServlet
                         pw.print(String.valueOf(ref.getBundle().getBundleId()));
                         pw.println(">");
                     }
+                    pw.println();
                 }
                 pw.println();
             }
@@ -1111,23 +1064,11 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print("Name : ");
                     pw.println(filter.name);
                     final ServiceReference<?> ref = this.getServiceReference(filter.serviceId);
-                    if ( ref != null )
-                    {
-                        int ranking = 0;
-                        final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                        if ( obj instanceof Integer)
-                        {
-                            ranking = (Integer)obj;
-                        }
-                        pw.print("Ranking : ");
-                        pw.println(String.valueOf(ranking));
-                    }
+                    printServiceIdAndRanking(pw, ref, filter.serviceId);
                     pw.print("async : ");
                     pw.println(String.valueOf(filter.asyncSupported));
                     pw.print("dispatcher : ");
                     pw.println(getValueAsString(filter.dispatcher));
-                    pw.print("service.id : ");
-                    pw.println(String.valueOf(filter.serviceId));
                     if ( ref != null )
                     {
                         pw.print("Bundle : ");
@@ -1150,20 +1091,7 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print("Prefix : ");
                     pw.println(rsrc.prefix);
                     final ServiceReference<?> ref = this.getServiceReference(rsrc.serviceId);
-                    if ( ref != null )
-                    {
-                        int ranking = 0;
-                        final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                        if ( obj instanceof Integer)
-                        {
-                            ranking = (Integer)obj;
-                        }
-                        pw.print("Ranking : ");
-                        pw.println(String.valueOf(ranking));
-                    }
-                    pw.print("service.id : ");
-                    pw.println(String.valueOf(rsrc.serviceId));
-                    pw.println();
+                    printServiceIdAndRanking(pw, ref, rsrc.serviceId);
                     if ( ref != null )
                     {
                         pw.print("Bundle : ");
@@ -1172,6 +1100,7 @@ public class HttpServicePlugin extends HttpServlet
                         pw.print(String.valueOf(ref.getBundle().getBundleId()));
                         pw.println(">");
                     }
+                    pw.println();
                 }
                 pw.println();
 
@@ -1195,21 +1124,9 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print("Name : ");
                     pw.println(ep.name);
                     final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-                    if ( ref != null )
-                    {
-                        int ranking = 0;
-                        final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                        if ( obj instanceof Integer)
-                        {
-                            ranking = (Integer)obj;
-                        }
-                        pw.print("Ranking : ");
-                        pw.println(String.valueOf(ranking));
-                    }
+                    printServiceIdAndRanking(pw, ref, ep.serviceId);
                     pw.print("async : ");
                     pw.println(String.valueOf(ep.asyncSupported));
-                    pw.print("service.id : ");
-                    pw.println(String.valueOf(ep.serviceId));
                     if ( ref != null )
                     {
                         pw.print("Bundle : ");
@@ -1231,19 +1148,7 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print("Types : ");
                     pw.println(getValueAsString(ep.types));
                     final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-                    if ( ref != null )
-                    {
-                        int ranking = 0;
-                        final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                        if ( obj instanceof Integer)
-                        {
-                            ranking = (Integer)obj;
-                        }
-                        pw.print("Ranking : ");
-                        pw.println(String.valueOf(ranking));
-                    }
-                    pw.print("service.id : ");
-                    pw.println(String.valueOf(ep.serviceId));
+                    printServiceIdAndRanking(pw, ref, ep.serviceId);
                     if ( ref != null )
                     {
                         pw.print("Bundle : ");
@@ -1271,8 +1176,7 @@ public class HttpServicePlugin extends HttpServlet
                 pw.println(getErrorText(ctxDto.failureReason));
                 pw.print("Path : ");
                 pw.println(getContextPath(ctxDto.contextPath));
-                pw.print("service.id : ");
-                pw.println(String.valueOf(ctxDto.serviceId));
+                printServiceIdAndRanking(pw, this.getServiceReference(ctxDto.serviceId), ctxDto.serviceId);
                 pw.println();
             }
         }
@@ -1288,22 +1192,9 @@ public class HttpServicePlugin extends HttpServlet
                 pw.print("Name : ");
                 pw.println(servlet.name);
                 final ServiceReference<?> ref = this.getServiceReference(servlet.serviceId);
-                if ( ref != null )
-                {
-                    int ranking = 0;
-                    final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                    if ( obj instanceof Integer)
-                    {
-                        ranking = (Integer)obj;
-                    }
-                    pw.print("Ranking : ");
-                    pw.println(String.valueOf(ranking));
-                }
+                printServiceIdAndRanking(pw, ref, servlet.serviceId);
                 pw.print("async : ");
                 pw.println(String.valueOf(servlet.asyncSupported));
-                pw.print("service.id : ");
-                pw.println(String.valueOf(servlet.serviceId));
-                pw.println();
                 if ( ref != null )
                 {
                     pw.print("Bundle : ");
@@ -1312,6 +1203,7 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print(String.valueOf(ref.getBundle().getBundleId()));
                     pw.println(">");
                 }
+                pw.println();
             }
             pw.println();
         }
@@ -1337,23 +1229,11 @@ public class HttpServicePlugin extends HttpServlet
                 pw.print("Name : ");
                 pw.println(filter.name);
                 final ServiceReference<?> ref = this.getServiceReference(filter.serviceId);
-                if ( ref != null )
-                {
-                    int ranking = 0;
-                    final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                    if ( obj instanceof Integer)
-                    {
-                        ranking = (Integer)obj;
-                    }
-                    pw.print("Ranking : ");
-                    pw.println(String.valueOf(ranking));
-                }
+                printServiceIdAndRanking(pw, ref, filter.serviceId);
                 pw.print("async : ");
                 pw.println(String.valueOf(filter.asyncSupported));
                 pw.print("dispatcher : ");
                 pw.println(getValueAsString(filter.dispatcher));
-                pw.print("service.id : ");
-                pw.println(String.valueOf(filter.serviceId));
                 if ( ref != null )
                 {
                     pw.print("Bundle : ");
@@ -1378,20 +1258,7 @@ public class HttpServicePlugin extends HttpServlet
                 pw.print("Prefix : ");
                 pw.println(rsrc.prefix);
                 final ServiceReference<?> ref = this.getServiceReference(rsrc.serviceId);
-                if ( ref != null )
-                {
-                    int ranking = 0;
-                    final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                    if ( obj instanceof Integer)
-                    {
-                        ranking = (Integer)obj;
-                    }
-                    pw.print("Ranking : ");
-                    pw.println(String.valueOf(ranking));
-                }
-                pw.print("service.id : ");
-                pw.println(String.valueOf(rsrc.serviceId));
-                pw.println();
+                printServiceIdAndRanking(pw, ref, rsrc.serviceId);
                 if ( ref != null )
                 {
                     pw.print("Bundle : ");
@@ -1400,6 +1267,7 @@ public class HttpServicePlugin extends HttpServlet
                     pw.print(String.valueOf(ref.getBundle().getBundleId()));
                     pw.println(">");
                 }
+                pw.println();
             }
             pw.println();
 
@@ -1425,21 +1293,9 @@ public class HttpServicePlugin extends HttpServlet
                 pw.print("Name : ");
                 pw.println(ep.name);
                 final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-                if ( ref != null )
-                {
-                    int ranking = 0;
-                    final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                    if ( obj instanceof Integer)
-                    {
-                        ranking = (Integer)obj;
-                    }
-                    pw.print("Ranking : ");
-                    pw.println(String.valueOf(ranking));
-                }
+                printServiceIdAndRanking(pw, ref, ep.serviceId);
                 pw.print("async : ");
                 pw.println(String.valueOf(ep.asyncSupported));
-                pw.print("service.id : ");
-                pw.println(String.valueOf(ep.serviceId));
                 if ( ref != null )
                 {
                     pw.print("Bundle : ");
@@ -1463,19 +1319,7 @@ public class HttpServicePlugin extends HttpServlet
                 pw.print("Reason : ");
                 pw.println(getErrorText(ep.failureReason));
                 final ServiceReference<?> ref = this.getServiceReference(ep.serviceId);
-                if ( ref != null )
-                {
-                    int ranking = 0;
-                    final Object obj = ref.getProperty(Constants.SERVICE_RANKING);
-                    if ( obj instanceof Integer)
-                    {
-                        ranking = (Integer)obj;
-                    }
-                    pw.print("Ranking : ");
-                    pw.println(String.valueOf(ranking));
-                }
-                pw.print("service.id : ");
-                pw.println(String.valueOf(ep.serviceId));
+                printServiceIdAndRanking(pw, ref, ep.serviceId);
                 if ( ref != null )
                 {
                     pw.print("Bundle : ");
